<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
      @submit.native.prevent
    >
      <el-form-item label="舰船名称" prop="shipName">
        <el-input
          v-model="queryParams.shipName"
          placeholder="请输入舰船名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:ships:add']"
          >新增</el-button
        >
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="shipsList"
      @selection-change="handleSelectionChange"
    >
      <!-- <el-table-column type="selection" width="55" align="center" /> -->
      <el-table-column label="舰船编号" align="center" prop="shipId" />
      <el-table-column label="舰船名称" align="center" prop="shipName" />
      <el-table-column label="舰船类型" align="center" prop="shipType" />
      <el-table-column label="舰船型号" align="center" prop="shipDesign" />
      <!-- <el-table-column
        label="舰船类型(船舰类型(1驱逐舰;2护卫舰;3登陆舰;4扫雷舰;5拖船;6油船;))"
        align="center"
        prop="shipType"
      /> -->
      <el-table-column label="所属码头" align="center" prop="whName" />
      <el-table-column label="所属泊位" align="center" prop="beName" />
      <!-- <el-table-column label="target" align="center" prop="target" />
      <el-table-column label="position" align="center" prop="position" /> -->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:ships:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:ships:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改舰船对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="舰船名称" prop="shipName">
          <el-input v-model="form.shipName" placeholder="请输入舰船名称" />
        </el-form-item>
        <!-- <el-row>
          <el-col :span="12"> -->
        <el-form-item label="舰船类型" prop="shipTypeId">
          <el-select
            v-model="form.shipTypeId"
            placeholder="舰船类型"
            clearable
            @change="getShipDesign"
          >
            <el-option
              v-for="s in shipTypeOptions"
              :key="s.id"
              :label="s.typeName + '-' + s.shipDesign"
              :value="s.id"
            />
          </el-select>
        </el-form-item>
        <!-- <el-form-item label="舰船型号" prop="shipDesign">
          <el-input v-model="form.shipDesign" disabled="true" placeholder="请输入舰船概述" />
        </el-form-item> -->
        <!-- </el-col>
          <el-col :span="12"> -->
        <el-form-item label="舰船编号" prop="shipId">
          <el-input v-model="form.shipId" placeholder="请输入舰船概述" />
        </el-form-item>
        <!-- </el-col>
        </el-row> -->

        <!-- <el-form-item label="舰船概述" prop="shipOverview">
          <el-input
            v-model="form.shipOverview"
            type="textarea"
            placeholder="请输入舰船概述"
          />
        </el-form-item>
        <el-form-item label="舰船参数" prop="shipParameters">
          <el-input
            v-model="form.shipParameters"
            type="textarea"
            placeholder="请输入舰船参数"
          />
        </el-form-item> -->
        <!-- <el-form-item label="position" prop="position">
          <el-input v-model="form.position" placeholder="请输入position" />
        </el-form-item>
        <el-form-item label="target " prop="target ">
          <el-input v-model="form.target" placeholder="请输入target" />
        </el-form-item> -->
        <el-row>
          <el-col :span="12">
            <el-form-item label="码头" prop="whId">
              <el-select v-model="form.whId" placeholder="请选择码头" @change="getBerth">
                <el-option
                  v-for="item in whOptions"
                  :key="item.pkId"
                  :label="item.harborName"
                  :value="item.pkId"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="泊位" prop="beId">
              <el-select v-model="form.beId" placeholder="请选择泊位">
                <el-option
                  v-for="item in beOptions"
                  :key="item.pkid"
                  :label="item.name"
                  :value="item.pkid"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>

        <!-- <el-form-item label="模型文件" prop="shipModel">
          <el-upload
            class="upload-demo"
            :action="uploadFileUrl"
            :on-remove="handleRemove"
            :on-success="handleAvatarSuccess"
            :file-list="fileList"
          >
            <el-button size="small" type="primary">点击上传</el-button>
          </el-upload>
        </el-form-item> -->
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listShips, getShips, delShips, addShips, updateShips } from "@/api/manage/ships";
import { listAll } from "@/api/manage/stock";
import { beList } from "@/api/manage/berth";
import { listAlldpShipTypeList, getdpShipType } from "@/api/manage/shipType";
import { getDeviceList } from "@/api/manage/device";
const baseUrl = process.env.VUE_APP_BASE_API;
export default {
  name: "Ships",
  dicts: ["dp_ship_type"],
  data() {
    return {
      // 遮罩层
      loading: true,
      fileList: [],
      imageUrl: "",
      // 选中数组
      ids: [],
      whOptions: [],
      //泊位选项
      beOptions: [],
      //舰船类型选项
      shipTypeOptions: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 舰船表格数据
      shipsList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        shipId: null,
        shipName: null,
        shipType: null,
        shipModel: null,
        shipOverview: null,
        shipParameters: null,
        updateTime: null,
        updateUser: null,
        whId: null,
        beId: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        shipId: [{ required: true, message: "舰船编号不能为空", trigger: "blur" }],
        shipType: [{ required: true, message: "舰船类型不能为空", trigger: "blur" }],
        shipName: [{ required: true, message: "舰船名称不能为空", trigger: "blur" }],
      },
      uploadFileUrl: baseUrl + "common/upload",
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询舰船列表 */
    getList() {
      this.loading = true;
      listShips(this.queryParams).then((response) => {
        this.shipsList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        shipId: null,
        shipName: null,
        shipType: null,
        shipModel: null,
        shipOverview: null,
        shipParameters: null,
        updateTime: null,
        updateUser: null,
        ID: null,
        whId: null,
        beId: null,
      };
      this.resetForm("form");
      this.fileList = [];
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.ID);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    getShipDesign(id) {
      getdpShipType(id).then((response) => {
        this.form.shipDesign = response.data.shipDesign;
        console.log(response.data);
      });
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.imageUrl = "";
      listAll().then((response) => {
        this.whOptions = response.data;
      });
      //获取舰船类型
      listAlldpShipTypeList().then((response) => {
        this.shipTypeOptions = response.data;
      });
      this.open = true;
      this.title = "添加舰船";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      listAll().then((response) => {
        this.whOptions = response.data;
      });
      beList(row.whId).then((response) => {
        this.beOptions = response.data;
      });
      //获取舰船类型
      listAlldpShipTypeList().then((response) => {
        this.shipTypeOptions = response.data;
      });
      const ID = row.id;
      getShips(ID).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改舰船";
        var fileListStr = response.data.shipModel;
        if (fileListStr) {
          console.log(fileListStr);
          if (fileListStr.endsWith(",")) {
            this.imageUrl = fileListStr;
            fileListStr = fileListStr.slice(0, -1); // 删除最后一个字符（逗号）
          } else {
            this.imageUrl = fileListStr + ",";
          }
          const arr = fileListStr.split(","); // 将文件路径字符串拆分成数组
          console.log("arr", arr);
          this.fileList = arr.map((item, index) => ({
            name: item.split("/").pop(), // 提取文件名
            url: baseUrl.slice(0, -1) + item, // 拼接完整的文件 URL
            status: "success", // 上传状态设置为成功
            uid: `uid-${index}`, // 使用唯一的 uid
          }));
          console.log("获取实体类转换后", this.fileList); // 检查文件列表
        } else {
          this.imageUrl = "";
        }
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateShips(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addShips(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const IDs = row.id;
      //查询是否有子设备
      getDeviceList(row.shipId).then((response) => {
        if (response.data.length > 0) {
          this.$message.error(row.shipName + "下有设备,请先删除相关设备后再删除!");
        } else {
          this.$modal
            .confirm('是否确认删除舰船名为"' + row.shipName + '"的数据项？')
            .then(function () {
              return delShips(IDs);
            })
            .then(() => {
              this.getList();
              this.$modal.msgSuccess("删除成功");
            })
            .catch(() => {});
        }
      });
    },
    //选中码头触发事件
    getBerth(whId) {
      this.form.beId = null;
      beList(whId).then((response) => {
        this.beOptions = response.data;
      });
    },
    handleRemove(file, fileList) {
      const remainingUrls = fileList.map((item) =>
        item.url.replace(baseUrl.slice(0, -1), "")
      );
      this.form.shipModel = remainingUrls.join(",");
      this.imageUrl = remainingUrls.join(",");
      console.log("删除完成", this.form.shipModel);
    },
    handleAvatarSuccess(res, file) {
      this.imageUrl += res.fileName + ",";
      this.form.shipModel = this.imageUrl;
      console.log("上传完成", this.form.shipModel);
    },
  },
};
</script>
